/*********************************************************************************
**
**   $Id: CustForm.cpp,v 1.6 2004/06/28 11:58:28 croftj Exp $
**   Copyright (c) 2004 Joe Croft <joe@croftj.net>
**   
**   This file is part of ah2.
**
**   ah2 is free software; you can redistribute it and/or modify
**   it under the terms of the GNU General Public License as published by
**   the Free Software Foundation; either version 2 of the License, or
**   (at your option) any later version.
**
**   Foobar is distributed in the hope that it will be useful,
**   but WITHOUT ANY WARRANTY; without even the implied warranty of
**   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**   GNU General Public License for more details.
**
**   You should have received a copy of the GNU General Public License
**   along with Foobar; if not, write to the Free Software
**   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
*********************************************************************************/

#include <qlistbox.h>
#include <qmessagebox.h>
#include <qregexp.h>
#include <qsqlquery.h>
#include "CustForm.h"

extern QSqlDatabase *autohouse;

CustForm::CustForm(QWidget *pParent, const char *pName, WFlags f) :
           DataForm(autohouse, "customers", 7, 6, pParent, pName, f)
{
   printf("CustForm::CustForm(): Enter()\n");
   fflush(stdout);

   inTransaction = false;

   nameEdit =     new QLineEdit(this);
   addrEdit =     new QLineEdit(this);
   cityEdit =     new QLineEdit(this);
   stateEdit =    new QLineEdit(this);
   zipEdit =      new QLineEdit(this);
   contactEdit =  new QLineEdit(this);
   tax_idEdit =   new QLineEdit(this);
   home_pnEdit =  new QLineEdit(this);
   work_pnEdit =  new QLineEdit(this);
   beeperEdit =   new QLineEdit(this);
   urlEdit =      new QLineEdit(this);
   emailEdit =    new QLineEdit(this);
   
   DataFields fields[] =
   {
      { "name",      "Name",           0,  0,  3,  0,  0,    0,   0, "",   nameEdit, NULL },
      { "addr",      "Addr",           1,  0,  3,  0,  0,    0,   0, "",   addrEdit, NULL },
      { "city",      "City",           2,  0,  0,  0,  0,    0,   0, "",   cityEdit, NULL },
      { "state",     "State",          2,  1,  0,  0,  3,    3,   0, "TX", stateEdit, NULL },
      { "zip",       "Zip",            2,  2,  0,  0,  8,   10,   0, "",   zipEdit, NULL },
      { "contact",   "Contact",        3,  0,  2,  0,  5,    0,   0, "",   contactEdit, NULL },
      { "tax_id",    "Tax ID",         3,  2,  0,  0,  5,    0,   0, "",   tax_idEdit, NULL },
      { "home_pn",   "Home Phone",     4,  0,  0,  0,  7,    0,   0, "",   home_pnEdit, NULL },
      { "work_pn",   "Work Phone",     4,  1,  0,  0,  7,    0,   0, "",   work_pnEdit, NULL },
      { "beeper",    "Beeper",         4,  2,  0,  0,  7,    0,   0, "",   beeperEdit, NULL },
      { "url",       "URL",            5,  0,  3,  0,  0,    0,   0, "",   urlEdit, NULL },
      { "email",     "EMail",          6,  0,  3,  0,  0,    0,   0, "",   emailEdit, NULL },
      {  NULL, NULL, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL }
   };
   printf("CustForm::CustForm(): Setting Fields()\n");
   fflush(stdout);
   setFields(fields);
   setEnabled(false);
   printf("CustForm::CustForm(): Exit()\n");
   fflush(stdout);
}

void CustForm::setEnabled(bool b)
{
   nameEdit->setEnabled(b);
   addrEdit->setEnabled(b);
   cityEdit->setEnabled(b);
   stateEdit->setEnabled(b);
   zipEdit->setEnabled(b);
   contactEdit->setEnabled(b);
   tax_idEdit->setEnabled(b); 
   home_pnEdit->setEnabled(b);
   work_pnEdit->setEnabled(b);
   beeperEdit->setEnabled(b);
   urlEdit->setEnabled(b);
   emailEdit->setEnabled(b);
}

void CustForm::setReadOnly(bool b)
{
   nameEdit->setReadOnly(b);
   addrEdit->setReadOnly(b);
   cityEdit->setReadOnly(b);
   stateEdit->setReadOnly(b);
   zipEdit->setReadOnly(b);
   contactEdit->setReadOnly(b);
   tax_idEdit->setReadOnly(b); 
   home_pnEdit->setReadOnly(b);
   work_pnEdit->setReadOnly(b);
   beeperEdit->setReadOnly(b);
   urlEdit->setReadOnly(b);
   emailEdit->setReadOnly(b);
}

void CustForm::deleteRecord() 
{
   QString s;
   printf("CustForm::deleteRecord(): Enter()\n");
   fflush(stdout);
   s = "Deletng Customer '" +
        nameEdit->text() +
        "'. This operation cannot be undone, Are you sure?"; 
   printf("CustForm::deleteRecord(): Opening Message Box\n");
   fflush(stdout);
   if (QMessageBox::warning(NULL, "Delete Transaction", s, QMessageBox::Yes | QMessageBox::Default, 
                           QMessageBox::No | QMessageBox::Escape) == QMessageBox::Yes) 
   {
      printf("CustForm::deleteRecord(): deleting record()\n");
      fflush(stdout);
      DataForm::deleteRecord();
   }
   printf("CustForm::deleteRecord(): Exit()\n");
   fflush(stdout);
}

void CustForm::insertRecord()
{
   beginTransaction();
   DataForm::insertRecord();  
   setEnabled(true);
}

void CustForm::updateRecord()
{
   beginTransaction();
   DataForm::updateRecord();  
   setEnabled(true);
}

void CustForm::beginTransaction()
{
   if ( ! inTransaction ) 
   {
      DataForm::beginTransaction();
      inTransaction = true;
   }
}

void CustForm::commitTransaction()
{
   if ( inTransaction ) 
   {
      DataForm::commitTransaction();
      inTransaction = false;
   }
}

void CustForm::rollbackTransaction()
{
   if ( inTransaction ) 
   {
      DataForm::rollbackTransaction();
      inTransaction = false;
   }
}

bool CustForm::isInTransaction()
{
   printf("CustForm::isInTransaction(): inTransaction = %x\n", inTransaction);
   fflush(stdout);
   return(inTransaction);
}

void CustForm::refresh(QSqlRecord *r)
{
   printf("CustForm::isInTransaction(): inTransaction = %x\n", inTransaction);
   fflush(stdout);
   if ( r != NULL ) 
   {
      DataForm::refresh(r);
      setEnabled(true);
   }
}

void CustForm::refresh(QString s)
{
   printf("CustForm::isInTransaction(): inTransaction = %x\n", inTransaction);
   fflush(stdout);
   DataForm::refresh(s);
   setEnabled(true);
}


